/*		Copyright © 1997–2000  Jens Kilian
 *
 *		This program is free software; you can redistribute it and/or modify
 *		it under the terms of the GNU General Public License as published by
 *		the Free Software Foundation; either version 1, or (at your option)
 *		any later version.
 *
 *		This program is distributed in the hope that it will be useful,
 *		but WITHOUT ANY WARRANTY; without even the implied warranty of
 *		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
 *		GNU General Public License for more details.
 *
 *		You should have received a copy of the GNU General Public License
 *		along with this program; if not, write to the Free Software
 *		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *		Interface definitions for the Csound Server.
 */

#ifndef CSSVINTERFACE_H
#define CSSVINTERFACE_H

#include <OS.h>

#ifdef __cplusplus
	extern "C" {
#endif

/* Declarations from Csound. */
#include "cwindow.h"

/* Clients communicate with the server via a named port. */
#define kServerPortName "Csound Server"

/* Messages passed across this port (and others). */
enum {
	kServerNewAudioInPort	= 'naip',	/* accept a new audio input port */
	kServerNewAudioOutPort	= 'naop',	/* accept a new audio output port */
	kServerNewClientPort		= 'ncpt',	/* accept a new client port */
	kServerNewMidiInPort		= 'nmip',	/* accept a new MIDI input port */
	kServerNewMidiOutPort	= 'nmop',	/* accept a new MIDI output port */

	kServerNewGraphWindow	= 'ngwn',	/* create new graph window */
	kServerDrawGraph			= 'draw',	/* draw graph data */
	kServerNewInputWindow	= 'niwn',	/* create new X/Y input window */
	kServerReadInput			= 'read',	/* read X/Y position */
	kServerKillWindow			= 'kwin',	/* kill window */
	
	kServerQuit					= 'quit'
};

/* Maximal number of data points in a graph. */
#define kMaxGraphPoints 1024ul

/* Structure describing an audio connection. */
struct ServerAudioPort {
	port_id mPort;
	int mNumChannels;
	int mSampleFormat;
	float mSampleRate;
	size_t mBufferSize;
};

/* Structure describing a client connection. */
struct ServerClientPort {
	port_id mRequestPort;
	port_id mReplyPort;
};

/* Structure describing a MIDI connection. */
struct ServerMidiPort {
	port_id mPort;
	thread_id mClientThread;
};

/* Structures describing window requests. */
struct ServerGraphWindow {
	int32 mSerialNo;
	float mX, mY, mW, mH;
};

struct ServerGraphData {
	int32 mSerialNo;
	uint32 mAxesLineCount;
	uint32 mGraphLineCount;
	float mMidAxis;
};

struct ServerInputWindow {
	int32 mSerialNo;
	float mValueX, mValueY;
	float mX, mY, mW, mH;
};

struct ServerInputRequest {
	int32 mSerialNo;
};

struct ServerInputReply {
	float mValueX, mValueY;
	int mDown;
};

struct ServerKillWindow {
	int32 mSerialNo;
};

/* Buffer size for message exchange. */
union ServerMessage {
	struct ServerAudioPort mAudioPort;
	struct ServerClientPort mClientPort;
	struct ServerMidiPort mMidiPort;
	struct ServerGraphWindow mGraphWindow;
	struct ServerGraphData mGraphData;
	struct ServerInputWindow mInputWindow;
	struct ServerInputRequest mInputRequest;
	struct ServerInputReply mInputReply;
	struct ServerKillWindow mKillWindow;
	float mGraphPoints[kMaxGraphPoints * 2];
};
#define ServerBufferSize sizeof(union ServerMessage)

#ifdef __cplusplus
	}
#endif

#endif /* CSSVINTERFACE_H */
