//		Copyright © 1997	Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		Graphics view class for the Csound Server.

#ifndef CSSVGRAPHICSVIEW_H
#define CSSVGRAPHICSVIEW_H

#include <List.h>
#include <Point.h>
#include <Rect.h>
#include <View.h>

#include "CsSvAbstractView.h"
#include "CsSvInterface.h"

class CsoundServerGraphicsView : public CsoundServerAbstractView {
public:
	typedef CsoundServerAbstractView inherited;
	
	CsoundServerGraphicsView(BRect windowFrame, const char *pWindowName);
	virtual ~CsoundServerGraphicsView(void);

	// Hook functions.
	virtual void Draw(BRect updateRect);
	virtual void KeyDown(const char *pBytes, int32 nBytes);
	
	// Add a new page of data.
	void AddPage(const ServerGraphData *pDesc,
					 const float *pAxesPoints, const float *pGraphPoints,
					 const char *pCaption);
	
private:
	CsoundServerGraphicsView(const CsoundServerGraphicsView &orig);
	CsoundServerGraphicsView &operator =(
		const CsoundServerGraphicsView &orig);

	// Data members.
	BList mPages;
	uint32 mCurrentPage;
	
	// Private class for storing data pages.
	class CsoundServerGraphicsPage {
	public:
		CsoundServerGraphicsPage(const ServerGraphData *pDesc,
										 const float *pAxesPoints,
										 const float *pGraphPoints,
										 const char *pCaption);
		~CsoundServerGraphicsPage(void);
	
		const char *Caption(void) const
		{
			return mpCaption;
		}
		void DrawOn(BView *pView) const;
		
	private:
		CsoundServerGraphicsPage(const CsoundServerGraphicsPage &orig);
		CsoundServerGraphicsPage &operator =(
			const CsoundServerGraphicsPage &orig);
		
		// Data members.	
		const uint32 mAxesLineCount;
		BPoint *const mpAxesPoints;
		const uint32 mGraphLineCount;
		BPoint *const mpGraphPoints;
		char *const mpCaption;
		const float mMidAxis;
	};
};

#endif // CSSVGRAPHICSVIEW_H
