//		Copyright © 1997	Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		X/Y input view class for the Csound Server.

#include <OS.h>
#include <Point.h>
#include <Rect.h>

#include "CsSvInputView.h"

CsoundServerInputView::CsoundServerInputView(
	BRect windowFrame, const char *pWindowName,
	float x, float y)
:	inherited(windowFrame, pWindowName),
	mX(x),
	mY(y),
	mDown(false),
	mTracking(false)
{
	// empty
}

CsoundServerInputView::~CsoundServerInputView(void)
{
	// empty
}

void
CsoundServerInputView::Draw(BRect)
{
	const rgb_color drawColor = { 255, 255, 255, 0 };
	DrawCrosshairs(drawColor);
}

//void
//CsoundServerInputView::MouseDown(BPoint point)
//{
//	const double sample_interval = 25.0 * 1000.0;
//	BRect bounds = Bounds();
//	int32 buttons;
//	if (Window()->CurrentMessage()->FindInt32("buttons", &buttons)
//		 == B_NO_ERROR) {
//		while (buttons) {
//			Update(bounds, point, true);
//			UnlockLooper();
//			snooze(sample_interval);
//			if (!LockLooper()) {
//				// All hell breaks loose, probably.
//				return;
//			}
//			GetMouse(&point, (uint32 *)&buttons, TRUE);
//		}
//	}
//	Update(bounds, point, false);
//}

void
CsoundServerInputView::MouseDown(BPoint point)
{
	mTracking = true;
	SetMouseEventMask(B_POINTER_EVENTS,
							B_LOCK_WINDOW_FOCUS|B_NO_POINTER_HISTORY);
	Update(Bounds(), point, true);
}

void
CsoundServerInputView::MouseMoved(
	BPoint point, uint32 /*transit*/, const BMessage * /*pMsg*/)
{
	if (mTracking) {
		Update(Bounds(), point, true);
	}
}

void
CsoundServerInputView::MouseUp(BPoint point)
{
	if (mTracking) {
		mTracking = false;
		Update(Bounds(), point, false);
	}
}

void
CsoundServerInputView::GetState(float &x, float &y, int &down)
{
	x = mX;
	y = mY;
	down = (int)mDown;
}

void
CsoundServerInputView::DrawCrosshairs(rgb_color color)
{
	BRect bounds = Bounds();
	float x = bounds.left + mX * bounds.Width();
	float y = bounds.top  + mY * bounds.Height();
	BeginLineArray(2);
	AddLine(BPoint(bounds.left, y), BPoint(bounds.right, y), color);
	AddLine(BPoint(x, bounds.top), BPoint(x, bounds.bottom), color);
	EndLineArray();
}

void
CsoundServerInputView::Update(BRect bounds, BPoint point, bool down)
{
	const rgb_color eraseColor = { 0, 0, 0, 0 };

	float x = (point.x - bounds.left) / bounds.Width();
	float y = (point.y - bounds.top) / bounds.Height();
	x = (x < 0.0) ? 0.0 : (x > 1.0) ? 1.0 : x;
	y = (y < 0.0) ? 0.0 : (y > 1.0) ? 1.0 : y;
	if (x != mX || y != mY) {
		DrawCrosshairs(eraseColor);
		mX = x;
		mY = y;
		Draw(bounds);
		Flush();
	}
	mDown = down;
}
