//		Copyright © 1997	Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		Window class for the Csound Server.

#include <Autolock.h>
#include <List.h>
#include <Locker.h>
#include <Rect.h>
#include <Window.h>

#include "CsSvInterface.h"
#include "CsSvWindow.h"

// Static data members.
BList CsoundServerWindow::smWindowList;
BLocker CsoundServerWindow::smWindowListLocker;

CsoundServerWindow::CsoundServerWindow(
	BRect windowFrame, const char *pWindowName, const CsoundServerWindow::ID id)
:	inherited(windowFrame, pWindowName, B_TITLED_WINDOW, 0),
	mId(id)
{
	// Add to window list.
	BAutolock locker(smWindowListLocker);
	smWindowList.AddItem(this);
}

CsoundServerWindow::~CsoundServerWindow(void)
{
	// empty
}

bool
CsoundServerWindow::QuitRequested(void)
{
	// Remove from window list.
	BAutolock locker(smWindowListLocker);
	smWindowList.RemoveItem(this);

	return true;
}

CsoundServerWindow *
CsoundServerWindow::Find(const CsoundServerWindow::ID &id)
{
	BAutolock locker(smWindowListLocker);
	void *pItem;
	for (int32 i = 0; (pItem = smWindowList.ItemAt(i)) != 0; ++i) {
		CsoundServerWindow *const pWindow =
			static_cast<CsoundServerWindow *>(pItem);
		if (pWindow->mId == id) {
			return pWindow;
		}
	}
	return 0;
}
