//		Copyright © 1997	Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		Window class for the Csound Server.

#ifndef CSSVWINDOW_H
#define CSSVWINDOW_H

#include <List.h>
#include <Locker.h>
#include <Rect.h>
#include <Window.h>

class CsoundServerWindow: public BWindow {
public:
	typedef BWindow inherited;

	class ID {
	public:
		ID(uint32 clientId, uint32 serialNo)
		:	mClientId(clientId), mSerialNo(serialNo)
		{
			// empty
		}
		ID(const ID &id)
		:	mClientId(id.mClientId), mSerialNo(id.mSerialNo)
		{
			// empty
		}
		bool operator ==(const ID &id) const
		{
			return mClientId == id.mClientId && mSerialNo == id.mSerialNo;
		}
	
	private:
		const uint32 mClientId;
		const uint32 mSerialNo;
	};
	
	CsoundServerWindow(BRect windowFrame, const char *pWindowName,
							 const ID id);
	virtual ~CsoundServerWindow(void);

	// Hook functions.
	virtual bool QuitRequested(void);
	
	// Find window by ID.
	static CsoundServerWindow *Find(const ID &id);
	
private:
	CsoundServerWindow(const CsoundServerWindow &orig);
	CsoundServerWindow &operator =(const CsoundServerWindow &orig);
	
	// Data members.
	static BList smWindowList;
	static BLocker smWindowListLocker;
		
	const ID mId;
};

#endif // CSSVWINDOW_H
