//		Copyright © 2000  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		MIDI consumer class for the Csound Server.

#ifndef CSSVMIDICONSUMER_H
#define CSSVMIDICONSUMER_H

#include <List.h>
#include <Locker.h>
#include <MidiConsumer.h>
#include <OS.h>

class CsoundServerMidiConsumer : public BMidiLocalConsumer
{
	typedef BMidiLocalConsumer inherited;
public:
	CsoundServerMidiConsumer(
		const char *pName, const struct ServerMidiPort *pPort);
	virtual ~CsoundServerMidiConsumer(void);

	// Pass all received MIDI data to Csound in raw form.
	virtual void Data(uchar *pData, size_t length, bool atomic, bigtime_t time);	

	// Find an active consumer (needed to work around a bug in BMidiRoster).
	static CsoundServerMidiConsumer *Find(const char *pName);
	
private:
	CsoundServerMidiConsumer(const CsoundServerMidiConsumer &);
	CsoundServerMidiConsumer &operator =(const CsoundServerMidiConsumer &);

	// Thread functions.
	static int32 WatcherThreadStub(void *pData);
	int32 WatcherThread(void);

	// Data members.
	const port_id mPort;					// port to client
	const thread_id mClientThread;	// client's thread ID
	
	static BList smConsumerList;		// remove once BMidiRoster works
	static BLocker smConsumerListLocker;
};

#endif // CSSVMIDICONSUMER_H
