//		Copyright © 2000  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		MIDI producer class for the Csound Server.

#ifndef CSSVMIDIPRODUCER_H
#define CSSVMIDIPRODUCER_H

#include <List.h>
#include <Locker.h>
#include <MidiProducer.h>
#include <OS.h>

class CsoundServerMidiProducer : public BMidiLocalProducer
{
	typedef BMidiLocalProducer inherited;
public:
	CsoundServerMidiProducer(
		const char *pName, const struct ServerMidiPort *pPort);
	virtual ~CsoundServerMidiProducer(void);

	// Start processing data.
	status_t Run(void);
	
	// Find an active producer (needed to work around a bug in BMidiRoster).
	static CsoundServerMidiProducer *Find(const char *pName);
	
private:
	CsoundServerMidiProducer(const CsoundServerMidiProducer &);
	CsoundServerMidiProducer &operator =(const CsoundServerMidiProducer &);

	// Thread functions.
	static int32 ProducerThreadStub(void *pData);
	int32 ProducerThread(void);

	// Data members.
	const port_id mPort;		// port to client
	char *mpBuffer;			// buffer for MIDI data
	size_t mBufferSize;
	
	static BList smProducerList;				// remove once BMidiRoster works
	static BLocker smProducerListLocker;
};

#endif // CSSVMIDIPRODUCER_H
