//		Copyright © 2000  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		Interface to the BeOS software MIDI synthesizer.

#include "CsSvMidiSynthConsumer.h"

#include <MidiConsumer.h>
#include <MidiSynth.h>
#include <OS.h>

CsoundServerMidiSynthConsumer::CsoundServerMidiSynthConsumer(const char *pName)
:	inherited(pName)
{
	// Connect to the synthesizer and load instruments.
	mSynth.EnableInput(true, true);
}

CsoundServerMidiSynthConsumer::~CsoundServerMidiSynthConsumer(void)
{
	// empty
}

void
CsoundServerMidiSynthConsumer::NoteOff(
	uchar channel, uchar note, uchar velocity, bigtime_t time)
{
	snooze_until(time, B_SYSTEM_TIMEBASE);
	mSynth.NoteOff(channel, note, velocity);
}

void
CsoundServerMidiSynthConsumer::NoteOn(
	uchar channel, uchar note, uchar velocity, bigtime_t time)
{
	snooze_until(time, B_SYSTEM_TIMEBASE);
	mSynth.NoteOn(channel, note, velocity);
}

void
CsoundServerMidiSynthConsumer::KeyPressure(
	uchar channel, uchar note, uchar pressure, bigtime_t time)
{
	snooze_until(time, B_SYSTEM_TIMEBASE);
	mSynth.KeyPressure(channel, note, pressure);
}

void
CsoundServerMidiSynthConsumer::ControlChange(
	uchar channel, uchar controlNumber, uchar controlValue, bigtime_t time)
{
	snooze_until(time, B_SYSTEM_TIMEBASE);
	mSynth.ControlChange(channel, controlNumber, controlValue);
}

void
CsoundServerMidiSynthConsumer::ProgramChange(
	uchar channel, uchar programNumber, bigtime_t time)
{
	snooze_until(time, B_SYSTEM_TIMEBASE);
	mSynth.ProgramChange(channel, programNumber);
}

void
CsoundServerMidiSynthConsumer::ChannelPressure(
	uchar channel, uchar pressure, bigtime_t time)
{
	snooze_until(time, B_SYSTEM_TIMEBASE);
	mSynth.ChannelPressure(channel, pressure);
}

void
CsoundServerMidiSynthConsumer::PitchBend(
	uchar channel, uchar lsb, uchar msb, bigtime_t time)
{
	snooze_until(time, B_SYSTEM_TIMEBASE);
	mSynth.PitchBend(channel, lsb, msb);
}

void
CsoundServerMidiSynthConsumer::AllNotesOff(bool justChannel, bigtime_t time)
{
	snooze_until(time, B_SYSTEM_TIMEBASE);
	mSynth.AllNotesOff(justChannel);
}
