//		Copyright © 1997–2000  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		Application class for the Csound Server.

#ifndef CSSVAPPLICATION_H
#define CSSVAPPLICATION_H

#include <Application.h>
#include <Bitmap.h>
class BMidiEndpoint;
class BMidiProducer;
class BMidiConsumer;
#include <OS.h>

class CsoundServerMidiSynthConsumer;

class CsoundServerApplication : public BApplication
{
	typedef BApplication inherited;
public:
	CsoundServerApplication(void);
	virtual ~CsoundServerApplication(void);

	// Hook functions.
	virtual void AboutRequested(void);
	virtual bool QuitRequested(void);
	virtual void ReadyToRun(void);

private:
	CsoundServerApplication(const CsoundServerApplication &);
	CsoundServerApplication &operator =(const CsoundServerApplication &);

	// Handle the various client requests.
	static int32 ServerThreadStub(void *pData);
	int32 ServerThread(void) const;

	void NewAudioOutThread(struct ServerAudioPort *pDesc) const;
	static int32 AudioOutThread(void *pData);
	
	void NewClient(struct ServerClientPort *pDesc) const;

	void NewMidiInput(struct ServerMidiPort *pDesc) const;
	void NewMidiOutput(struct ServerMidiPort *pDesc) const;

	// Add icons to a MIDI endpoint.
	void AddIcons(BMidiEndpoint &endpoint) const;

	// Find MIDI endpoints by name.
	BMidiConsumer *FindConsumer(const char *pName) const;	
	BMidiProducer *FindProducer(const char *pName) const;	

	// Data members.
	port_id mServerPort;							// port known to clients
	thread_id mServerThread;					// thread monitoring the port
	sem_id mServerFinished;						// semaphore signaling end of thread
	
	BBitmap mLargeIcon;							// icons (for MIDI endpoints)
	BBitmap mMiniIcon;
	
	CsoundServerMidiSynthConsumer *mpSynth;// global software MIDI synthesizer
};

#endif // CSSVAPPLICATION_H
