//		Copyright © 2000  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		Sound player class for the Csound Server.

#ifndef CSSVSOUNDPLAYER_H
#define CSSVSOUNDPLAYER_H

#include <MediaDefs.h>
#include <OS.h>
#include <SoundPlayer.h>

class ServerAudioPort;

class CsoundServerSoundPlayer : public BSoundPlayer
{
	typedef BSoundPlayer inherited;
public:
	CsoundServerSoundPlayer(const ServerAudioPort &port, sem_id finished);
	virtual ~CsoundServerSoundPlayer(void);

private:
	CsoundServerSoundPlayer(const CsoundServerSoundPlayer &);
	CsoundServerSoundPlayer &operator =(const CsoundServerSoundPlayer &);
	
	static media_raw_audio_format *ConstructFormat(
		const ServerAudioPort &port,
		media_raw_audio_format &format);
	static size_t BytesPerSample(int format);
	
	static void PlayStub(void *pCookie, void *pBuffer, size_t size,
								const media_raw_audio_format &format);
	void Play(void *pBuffer, size_t size, const media_raw_audio_format &format);
	void ConvertSamples(const char *pBuffer, float *pOut, size_t nSamples);
	
	// Data members.
	media_raw_audio_format mFormat;
	port_id mPort;
	int mSampleFormat;
	const size_t mBytesPerSample;
	size_t mBufferSize;
	char *mpBuffer;
	size_t mBufferStart;
	size_t mBufferLimit;
	sem_id mFinished;
};

#endif // CSSVSOUNDPLAYER_H
