//		Copyright © 1997–2000  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		The environment variable window for Csound.

#include <cstring>
#include <cmath>

#include <Font.h>
#include <Point.h>
#include <Rect.h>
#include <TextControl.h>
#include <View.h>

#include "CsAbstractJob.h"
#include "CsEnvJob.h"
#include "CsAbstractMainWindow.h"
#include "CsEnvMainWindow.h"

// Message fields.
static const char kFieldWhichFile[] = "CsWhich";

// UI description data.
const CsoundAbstractWindow::FilenameDescriptor kTextControlDescriptors[] =
{
	{	"sfdir", "SFDIR", CsoundAbstractWindow::kNormal,
		CsoundEnvironmentJob::kSoundfileDirectory
	},
	{	"ssdir", "SSDIR", CsoundAbstractWindow::kNormal,
		CsoundEnvironmentJob::kSoundSampleDirectory
	},
	{	"sadir", "SADIR", CsoundAbstractWindow::kNormal,
		CsoundEnvironmentJob::kSoundAnalysisDirectory
	}
};

CsoundEnvironmentMainWindow::CsoundEnvironmentMainWindow(
	BPoint origin, const char *pTitle, const CsoundEnvironmentJob &job)
:	inherited(origin, pTitle, job)
{
	// Create all the controls and determine space requirements.
	uint32 i;
	float maxWidth = 0;
	float maxDivider = 0;

	CsoundAbstractWindow::ControlDimensions textControlDimensions[kNumTextControls];
	CreateControls(kNumTextControls,
						kTextControlDescriptors,
						mpTextControls,
						textControlDimensions,
						*this);
	for (i = 0; i < kNumTextControls; ++i) {
		const CsoundAbstractWindow::ControlDimensions &dim =
			textControlDimensions[i];
		if (dim.width > maxWidth) {
			maxWidth = dim.width;
		}
		if (dim.divider > maxDivider) {
			maxDivider = dim.divider;
		}
	}

	// Calculate overall space requirements and adjust sizes.
	if (maxDivider + 200 > maxWidth) {
		maxWidth = maxDivider + 200;
	}	
	
	for (i = 0; i < kNumTextControls; ++i) {
		BTextControl *pControl = mpTextControls[i];
		// The following had to be empirically determined :-(
		pControl->ResizeTo(maxWidth, textControlDimensions[i].height);
		pControl->SetDivider(maxDivider);
		pControl->TextView()->ResizeTo(maxWidth-maxDivider-10,
												 pControl->TextView()->Frame().Height());
	}
	
	// Lay out the controls.
	BView *const pBackgroundView = BackgroundView();
	
	font_height fontHeight;
	be_bold_font->GetHeight(&fontHeight);
	const float spacing =
		ceil((fontHeight.ascent + fontHeight.descent + fontHeight.leading) / 2);
	
	float y = spacing;
	mpTextControls[kSoundfileDirectory]->MoveTo(spacing, y);
	mpTextControls[kSoundSampleDirectory]->MoveTo(spacing,
																 y += textControlDimensions[0].height);
	mpTextControls[kSoundAnalysisDirectory]->MoveTo(spacing,
																	y += textControlDimensions[1].height);
	pBackgroundView->AddChild(mpTextControls[kSoundfileDirectory]);
	pBackgroundView->AddChild(mpTextControls[kSoundSampleDirectory]);
	pBackgroundView->AddChild(mpTextControls[kSoundAnalysisDirectory]);
	
	const float preferredWidth = maxWidth + 2 * spacing;
	const float preferredHeight =
		mpTextControls[kSoundAnalysisDirectory]->Frame().bottom + spacing;

	// Resize to final dimensions.
	pBackgroundView->ResizeTo(preferredWidth, preferredHeight);
	ResizeTo(preferredWidth, pBackgroundView->Frame().bottom);
}

CsoundEnvironmentMainWindow::~CsoundEnvironmentMainWindow(void)
{
	// empty
}

bool
CsoundEnvironmentMainWindow::QuitRequested(void)
{
	// Just hide - we are controlled by the application.
	Hide();
	return false;
}

void
CsoundEnvironmentMainWindow::UpdateControlValues(void)
{
	// Update all controls to their new values.
	SetControlValues(kNumTextControls,
						  kTextControlDescriptors,
						  mpTextControls,
						  *this);
	
	inherited::UpdateControlValues();
}

void
CsoundEnvironmentMainWindow::ValidJob(bool)
{
	// empty
}
