//		Copyright © 1997	Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		Describes a Csound fourier (CONVOLVE) analysis job.

#ifndef CSCVANALYSISJOB_H
#define CSCVANALYSISJOB_H

#include <Message.h>
#include <Path.h>
#include <SupportDefs.h>

#include "CsAbstractJob.h"

class CsoundCVAnalysisJob : public CsoundAbstractJob
{
	typedef CsoundAbstractJob inherited;
public:
	
	// Filename specifiers.
	enum {
		kInputFile,
		kOutputFile,
		
		kNumFilenames
	};
	
	// Numeric parameters.
	enum {
		kSampleRate,			// -s ...
		kChannel,				// -c ...
		kBeginTime,				// -b ...
		kDuration,				// -d ...
		
		kNumNumbers
	};

	CsoundCVAnalysisJob(
		bool assignName = true,
		uint32 numFilenames = kNumFilenames,
		uint32 numNumbers = kNumNumbers);
	CsoundCVAnalysisJob(const CsoundCVAnalysisJob &job);
	CsoundCVAnalysisJob &operator =(const CsoundCVAnalysisJob &job);	
	virtual ~CsoundCVAnalysisJob(void);

	virtual CsoundAbstractJob *New(void) const;
	virtual CsoundAbstractJob *Clone(void) const;
	virtual CsoundAbstractJob &Become(const CsoundAbstractJob &job);

	virtual bool operator ==(const CsoundAbstractJob &job) const;

	// Archiving methods.
	CsoundCVAnalysisJob(BMessage *pMsg);
	virtual status_t Archive(BMessage *pMsg, bool deep = true) const;
#pragma export on
	static CsoundCVAnalysisJob *Instantiate(BMessage *pMsg);
#pragma export reset

	// Check if the job is valid.
	virtual bool IsValid(void) const;
	
	// Return current directory for execution.
	virtual BPath CurrentDirectory(void) const;
	
	// Construct and return Csound command arguments.
	// The returned memory must be explicitly freed.
	virtual char **CopyCommandArguments(const char *prefix, int32 &nArgs) const;

	// Return a name for the class.
	virtual const char *JobClass(void) const;
	
	// Construct a title for a window.
	virtual char *CopyWindowTitle(void) const;

	// Create an instance of the concrete window class.
	virtual CsoundAbstractWindow *CreateWindow(BPoint origin) const;
};

#endif // CSCVANALYSISJOB_H
