//		Copyright © 1997–2000  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		Abstract window class for Csound.  Serves as a base class for all 
//		the dialog-oriented windows.

#ifndef CSABSTRACTWINDOW_H
#define CSABSTRACTWINDOW_H

#include <Button.h>
#include <CheckBox.h>
#include <Point.h>
#include <RadioButton.h>
#include <TextControl.h>
#include <View.h>
#include <Window.h>

class CsoundAbstractMainWindow;

class CsoundAbstractWindow : public BWindow
{
	typedef BWindow inherited;
public:
	
	CsoundAbstractWindow(BPoint origin,
								const char *pTitle,
								window_look look = B_TITLED_WINDOW_LOOK,
								window_feel feel = B_NORMAL_WINDOW_FEEL);
	virtual ~CsoundAbstractWindow(void);

	// Types for dialog creation; see below.
	struct ButtonDescriptor {
		const char *const pName;
		const char *const pLabel;
		const uint32 msgWhat;
	};

	struct CheckBoxDescriptor {
		const char *const pName;
		const char *const pLabel;
		const int32 option;
	};

	struct RadioButtonDescriptor {
		const char *const pName;
		const char *const pLabel;
		const int32 mask, value;
	};

	enum FilenameType {
		kNormal,
		kMandatory,
		kHasMenu
	};
	struct FilenameDescriptor {
		const char *const pName;
		const char *const pLabel;
		const FilenameType type;
		const int32 whichFile;
	};

	struct NumberDescriptor {
		const char *const pName;
		const char *const pLabel;
		const char *const pFormat;
		const int32 whichNumber;
	};

protected:
	// Create resp. return the window's background view.
	void CreateBackgroundView(
		BRect frame, const char *pTitle, rgb_color viewColor);
	BView *BackgroundView(void) const;
	
	// Update the UI controls when they are out of date.
	virtual void UpdateControlValues(void) = 0;

	// Utilities for dialog creation.  Each CreateControls() method creates
	// a bunch of controls which will send messages to the supplied main
	// window.  The controls are initialized from the main window's job
	// by the corresponding SetControlValues() method.
	struct ControlDimensions {
		float width, height, divider;
	};
	
	void CreateControls(const uint32 nItems,
							  const ButtonDescriptor descriptors[],
							  BButton *pControls[],
							  ControlDimensions dimensions[],
							  const CsoundAbstractMainWindow &target);

	void CreateControls(const uint32 nItems,
							  const CheckBoxDescriptor descriptors[],
							  BCheckBox *pControls[],
							  ControlDimensions dimensions[],
							  const CsoundAbstractMainWindow &target);
	void SetControlValues(const uint32 nItems,
								 const CheckBoxDescriptor descriptors[],
								 BCheckBox *pControls[],
								 const CsoundAbstractMainWindow &target);

	void CreateControls(const uint32 nItems,
							  const RadioButtonDescriptor descriptors[],
							  BRadioButton *pControls[],
							  ControlDimensions dimensions[],
							  const CsoundAbstractMainWindow &target);
	void SetControlValues(const uint32 nItems,
								 const RadioButtonDescriptor descriptors[],
								 BRadioButton *pControls[],
								 const CsoundAbstractMainWindow &target);

	void CreateControls(const uint32 nItems,
							  const FilenameDescriptor descriptors[],
							  BTextControl *pControls[],
							  ControlDimensions dimensions[],
							  const CsoundAbstractMainWindow &target);
	void SetControlValues(const uint32 nItems,
								 const FilenameDescriptor descriptors[],
								 BTextControl *pControls[],
								 const CsoundAbstractMainWindow &target);

	void CreateControls(const uint32 nItems,
							  const NumberDescriptor descriptors[],
							  BTextControl *pControls[],
							  ControlDimensions dimensions[],
							  const CsoundAbstractMainWindow &target);
	void SetControlValues(const uint32 nItems,
								 const NumberDescriptor descriptors[],
								 BTextControl *pControls[],
								 const CsoundAbstractMainWindow &target);

	const char *NumberToString(const char *pFormat, double value) const;
	double StringToNumber(const char *pFormat, const char *pString) const;
	
private:
	// Unimplemented copy constructor and assignment operator.
	CsoundAbstractWindow(const CsoundAbstractWindow &);
	CsoundAbstractWindow &operator =(const CsoundAbstractWindow &);
	
	// Data members.
	BView *mpBackgroundView;
};

inline BView *
CsoundAbstractWindow::BackgroundView(void) const
{
	return mpBackgroundView;
}

#endif // CSABSTRACTWINDOW_H
