//		Copyright © 1997–2000  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		The heterodyne filter analysis window for Csound.

#ifndef CSHFMAINWINDOW_H
#define CSHFMAINWINDOW_H

#include <Button.h>
#include <Message.h>
#include <Point.h>
#include <TextControl.h>

#include "CsHFJob.h"
#include "CsAbstractMainWindow.h"
class CsoundTranscriptWindow;

class CsoundHFAnalysisMainWindow : public CsoundAbstractMainWindow
{
	typedef CsoundAbstractMainWindow inherited;
public:
	
	CsoundHFAnalysisMainWindow(
		BPoint origin, const char *pTitle,
		const CsoundHFAnalysisJob &job = CsoundHFAnalysisJob());
	virtual ~CsoundHFAnalysisMainWindow(void);

	// Hook functions.
	virtual void MessageReceived(BMessage *pMsg);

	// Message codes.
	enum {
		kStartAnalysis				= 'strt',	// commands
		kAbortAnalysis				= 'abrt'
	};

protected:
	// Hook functions.
	virtual void UpdateControlValues(void);
	virtual void ValidJob(bool valid);
	
private:
	// Unimplemented copy constructor and assignment operator.
	CsoundHFAnalysisMainWindow(const CsoundHFAnalysisMainWindow &);
	CsoundHFAnalysisMainWindow &operator =(const CsoundHFAnalysisMainWindow &);

	// Controls - file names.
	enum {
		kInputFilename,						// name of sound input file
		kOutputFilename,						// name of analysis output file
		kTranscriptFilename,					// (optional) name of transcript file
		kNumFilenames
	};
	BTextControl *mpFilenames[kNumFilenames];
	
	// Numeric parameters.
	enum {
		kSampleRate,							// -s ...
		kChannel,								// -c ...
		kBeginTime,								// -b ...
		kDuration,								// -d ...
		kBeginFrequency,						// -f ...
		kNumPartials,							// -h ...
		kMaxAmplitude,							// -M ...
		kMinAmplitude,							// -m ...
		kNumBreakpoints,						// -n ...
		kLowPassFilter,						// -l ...
		kNumNumbers
	};
	BTextControl *mpNumbers[kNumNumbers];
	
	// Actions.
	enum {
		kStart,									// start analysis
		kAbort,									// abort analysis
		kNumButtons
	};
	BButton *mpButtons[kNumButtons];
	
	// Transcript window currently executing a job.
	CsoundTranscriptWindow *mpTranscriptWindow;
};

#endif // CSHFMAINWINDOW_H
