//		Copyright © 1997–2000  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		The linear predictive analysis window for Csound.

#ifndef CSLPMAINWINDOW_H
#define CSLPMAINWINDOW_H

#include <Button.h>
#include <Message.h>
#include <Point.h>
#include <TextControl.h>

#include "CsLPJob.h"
#include "CsAbstractMainWindow.h"
class CsoundTranscriptWindow;

class CsoundLPAnalysisMainWindow : public CsoundAbstractMainWindow
{
	typedef CsoundAbstractMainWindow inherited;
public:
	
	CsoundLPAnalysisMainWindow(
		BPoint origin, const char *pTitle,
		const CsoundLPAnalysisJob &job = CsoundLPAnalysisJob());
	virtual ~CsoundLPAnalysisMainWindow(void);

	// Hook functions.
	virtual void MessageReceived(BMessage *pMsg);

	// Message codes.
	enum {
		kStartAnalysis				= 'strt',	// commands
		kAbortAnalysis				= 'abrt'
	};

protected:
	// Hook functions.
	virtual void UpdateControlValues(void);
	virtual void ValidJob(bool valid);
	
private:
	// Unimplemented copy constructor and assignment operator.
	CsoundLPAnalysisMainWindow(const CsoundLPAnalysisMainWindow &);
	CsoundLPAnalysisMainWindow &operator =(const CsoundLPAnalysisMainWindow &);

	// Controls - file names.
	enum {
		kInputFilename,						// name of sound input file
		kOutputFilename,						// name of analysis output file
		kTranscriptFilename,					// (optional) name of transcript file
		kCommentString,						// comment string (not a file)
		kNumFilenames
	};
	BTextControl *mpFilenames[kNumFilenames];
	
	// Numeric parameters.
	enum {
		kSampleRate,							// -s ...
		kChannel,								// -c ...
		kBeginTime,								// -b ...
		kDuration,								// -d ...
		kNumPoles,								// -p ...
		kHopSize,								// -h ...
		kMinFrequency,							// -P ...
		kMaxFrequency,							// -Q ...
		kNumNumbers
	};
	BTextControl *mpNumbers[kNumNumbers];

	// Actions.
	enum {
		kStart,									// start analysis
		kAbort,									// abort analysis
		kNumButtons
	};
	BButton *mpButtons[kNumButtons];
	
	// Transcript window currently executing a job.
	CsoundTranscriptWindow *mpTranscriptWindow;
};

#endif // CSLPMAINWINDOW_H
