//		Copyright © 1997–2000  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		Application class for Csound.

#ifndef CSAPPLICATION_H
#define CSAPPLICATION_H

#include <Application.h>
#include <Entry.h>
#include <File.h>
#include <FilePanel.h>
#include <List.h>
#include <Menu.h>
#include <Message.h>
#include <Path.h>
#include <Window.h>

class CsoundEnvironmentJob;

class CsoundApplication : public BApplication {
	typedef BApplication inherited;
public:
	
	CsoundApplication(void);
	virtual ~CsoundApplication(void);

	// Message codes and fields.
	enum {
		kMainWindowCreated		= 'mwct',
		kMainWindowDestroyed		= 'mwdy',
		kOpenFile					= 'open'
	};
	static const char kFieldWindow[];

	// Hook functions.
	virtual void AboutRequested(void);
	virtual void ArgvReceived(int32 argc, char **ppArgv);
	virtual void MessageReceived(BMessage *pMsg);
	virtual bool QuitRequested(void);
	virtual void ReadyToRun(void);
	virtual void RefsReceived(BMessage *pMsg);

	// Get application signature and directory.
	static const char *GetSignature(void);
	static BPath GetDirectory(void);
	
	// Return a job describing environment variables.
	static const CsoundEnvironmentJob &EnvironmentJob(void);
	
	// Return list of prototype jobs.
	const BList &PrototypeJobs(void) const;

	// Construct a menu for switching between open windows.
	void ConstructWindowMenu(BMenu &menu);
	
private:
	// Unimplemented copy constructor and assignment operator.
	CsoundApplication(const CsoundApplication &);
	CsoundApplication &operator =(const CsoundApplication &);

	void ShowFilePanel(void);
	void OpenFile(const BEntry &entry);
	void SetEnvironment(const CsoundEnvironmentJob &job) const;
	static bool TryClosingWindow(void *pWin, void *pFlag);
	int ShortcutForWindow(BWindow *pWindow);
	void SetShortcut(BWindow *pOld, BWindow *pNew);
	static bool CreateWindowMenuItem(void *pWin, void *pMenu);
		
	// Static data members.
	static BWindow *smpEnvironmentWindow;	// special environment var window

	// Data members.
	BFilePanel *mpFilePanel;					// application file panel
	bool mFileSelectionPending;				// file panel currently open
	bool mWindowOpened;							// was a job opened during launch?
	BList mPrototypeJobs;						// prototypes of all concrete jobs
	BList mMainWindows;							// list of open main windows
	enum { kNumShortcuts = 10 };				// window menu shortcuts
	BWindow *mpShortcutWindows[kNumShortcuts];
};

inline const BList &
CsoundApplication::PrototypeJobs(void) const
{
	return mPrototypeJobs;
}

#endif // CSAPPLICATION_H
