//		Copyright © 1997–2000  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		The fourier (PVOC) analysis window for Csound.

#ifndef CSPVMAINWINDOW_H
#define CSPVMAINWINDOW_H

#include <Button.h>
#include <CheckBox.h>
#include <Message.h>
#include <Point.h>
#include <TextControl.h>

#include "CsPVJob.h"
#include "CsAbstractMainWindow.h"
class CsoundTranscriptWindow;

class CsoundPVAnalysisMainWindow : public CsoundAbstractMainWindow
{
	typedef CsoundAbstractMainWindow inherited;
public:
	
	CsoundPVAnalysisMainWindow(
		BPoint origin, const char *pTitle,
		const CsoundPVAnalysisJob &job = CsoundPVAnalysisJob());
	virtual ~CsoundPVAnalysisMainWindow(void);

	// Hook functions.
	virtual void MessageReceived(BMessage *pMsg);

	// Message codes.
	enum {
		kStartAnalysis				= 'strt',	// commands
		kAbortAnalysis				= 'abrt'
	};

protected:
	// Hook functions.
	virtual void UpdateControlValues(void);
	virtual void ValidJob(bool valid);
	
private:
	// Unimplemented copy constructor and assignment operator.
	CsoundPVAnalysisMainWindow(const CsoundPVAnalysisMainWindow &);
	CsoundPVAnalysisMainWindow &operator =(const CsoundPVAnalysisMainWindow &);

	// Controls - file names.
	enum {
		kInputFilename,						// name of sound input file
		kOutputFilename,						// name of analysis output file
		kTranscriptFilename,					// (optional) name of transcript file
		kTraceOutputFilename,				// (optional) name of text output file
		kNumFilenames
	};
	BTextControl *mpFilenames[kNumFilenames];
	
	// Numeric parameters.
	enum {
		kSampleRate,							// -s ...
		kChannel,								// -c ...
		kBeginTime,								// -b ...
		kDuration,								// -d ...
		kFrameSize,								// -n ...
		kWindowOverlap,						// -w ...
		kHopSize,								// -h ...
		kNumNumbers
	};
	BTextControl *mpNumbers[kNumNumbers];
	
	// Switches.
	enum {
		kDisplays,								// -g
		kNumCheckBoxes
	};
	BCheckBox *mpCheckBoxes[kNumCheckBoxes];
	
	// Actions.
	enum {
		kStart,									// start analysis
		kAbort,									// abort analysis
		kNumButtons
	};
	BButton *mpButtons[kNumButtons];
	
	// Transcript window currently executing a job.
	CsoundTranscriptWindow *mpTranscriptWindow;
};

#endif // CSPVMAINWINDOW_H
