//		Copyright © 1997–2000  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		The synthesis window for Csound.  Contains the most commonly needed
//		controls.

#ifndef CSSYNTHMAINWINDOW_H
#define CSSYNTHMAINWINDOW_H

class BButton;
class BCheckBox;
class BMessage;
#include <Point.h>
class BTextControl;

#include "CsSynthJob.h"
#include "CsAbstractMainWindow.h"
class CsoundSynthesisOptionsWindow;
class CsoundTranscriptWindow;

class CsoundSynthesisMainWindow : public CsoundAbstractMainWindow
{
	typedef CsoundAbstractMainWindow inherited;
public:
	
	CsoundSynthesisMainWindow(
		BPoint origin, const char *pTitle,
		const CsoundSynthesisJob &job = CsoundSynthesisJob());
	virtual ~CsoundSynthesisMainWindow(void);

	// Hook functions.
	virtual void MessageReceived(BMessage *pMsg);

	// Message codes.
	enum {
		kStartSynthesis				= 'strt',	// commands
		kAbortSynthesis				= 'abrt'
	};

protected:
	// Hook functions.
	virtual void UpdateControlValues(void);
	virtual void ValidJob(bool valid);
	virtual void AcceptDroppedRef(BPoint where, const entry_ref *pRef);
	
private:
	// Unimplemented copy constructor and assignment operator.
	CsoundSynthesisMainWindow(const CsoundSynthesisMainWindow &);
	CsoundSynthesisMainWindow &operator =(const CsoundSynthesisMainWindow &);

	// Controls - file names.
	enum {
		kOrchestraFilename,			// name of orchestra file
		kScoreFilename,				// name of score file
		kExtractFilename,				// (optional) name of extract file
		kInputFilename,				// (optional) name of sound input file
		kLineFilename,					// (optional) name of line-oriented
											//            realtime input device
		kMIDIInFilename,				// (optional) name of MIDI input file/device
		kOutputFilename,				// (optional) name of sound output file
		kMIDIOutFilename,				// (optional) name of MIDI output device
		kTranscriptFilename,			// (optional) name of transcript file
		kNumFilenames
	};
	BTextControl *mpFilenames[kNumFilenames];
	
	// On/off settings.
	enum {
//		kTranslateScore,				// -S (score is in SCOT format)
		kRealtimeMIDI,					// MIDI input from file (-F) or device (-M)
		kNumCheckBoxes
	};
	BCheckBox *mpCheckBoxes[kNumCheckBoxes];
	
	// Actions.
	enum {
		kStart,							// start synthesis
		kAbort,							// abort synthesis
		kNumButtons
	};
	BButton *mpButtons[kNumButtons];

	// Transcript window currently executing a job.
	CsoundTranscriptWindow *mpTranscriptWindow;
};

#endif // CSSYNTHMAINWINDOW_H
