//		Copyright © 1997–2000  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		The synthesis options window; contains less frequently used settings.

#ifndef CSSYNTHOPTIONSWINDOW_H
#define CSSYNTHOPTIONSWINDOW_H

#include <CheckBox.h>
#include <Point.h>
#include <RadioButton.h>

class CsoundSynthesisMainWindow;
#include "CsAbstractOptionsWindow.h"

class CsoundSynthesisOptionsWindow : public CsoundAbstractOptionsWindow
{
	typedef CsoundAbstractOptionsWindow inherited;
public:
	
	CsoundSynthesisOptionsWindow(
		BPoint origin, const char *pTitle, CsoundSynthesisMainWindow &target);
	virtual ~CsoundSynthesisOptionsWindow(void);

	// Hook functions.
	virtual void UpdateControlValues(void);

private:
	// Unimplemented copy constructor and assignment operator.
	CsoundSynthesisOptionsWindow(const CsoundSynthesisOptionsWindow &);
	CsoundSynthesisOptionsWindow &
		operator =(const CsoundSynthesisOptionsWindow &);

	// Controls - on/off settings.
	enum {
		kVerboseTranslation,						// -v
		kNoteAmplitudeMsgs,						// -m ...
		kOutOfRangeMsgs,
		kWarningMsgs,
		kHeartbeat,									// -H
		kNotifyAtEndOfJob,						// -N
		kPreprocessScore,							// -C
		kInitTimeOnly,								// -I
		kInhibitOutput,							// -n
		kRewriteSoundfileHdr,					// -R
		kDeferSoundfileLoads,					// -D
		kTerminateAtEndOfTrk,					// -T
		kNumCheckBoxes
	};
	BCheckBox *mpCheckBoxes[kNumCheckBoxes];
	
	// Numeric parameters.
	enum {
		kSoftwareSampleFrames,				// -b ...
		kHardwareSampleFrames,				// -B ...
		kSampleRateOverride,					// -r ...
		kControlRateOverride,				// -k ...
		kTempo,									// -t ...
//		kSustainPedalThreshold,				// -P ...
		kNumNumbers
	};
	BTextControl *mpNumbers[kNumNumbers];

	// 1-of-N selections.
	enum {
		kSigned8BitSamples,					// -c
		kUnsigned8BitSamples,				// -8
		kALawSamples,							// -a
		kmuLawSamples,							// -u
		kSigned16BitSamples,					// -s
		kSigned32BitSamples,					// -l
		kFloatSamples,							// -f

		kNoHeaderFormat,						// -h
		kSoundfileFormat,						// -J
		kAIFFFormat,							// -A
		kWAVFormat,								// -W

		kSuppressDisplays,					// -d
		kASCIIDisplays,						// -g
		kPostScriptDisplays,					// -G
		kGraphicsDisplays,					// (none)

		kNumRadioButtons
	};
	BRadioButton *mpRadioButtons[kNumRadioButtons];
};

#endif // CSSYNTHOPTIONSWINDOW_H
