//		Copyright © 1999–2000  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		A text control with associated pop-up menu of predefined strings.

#ifndef MENUTEXTCONTROL_H
#define MENUTEXTCONTROL_H

class BHandler;
class BMessage;
#include <Point.h>
class BPopUpMenu;
#include <Rect.h>
#include <TextControl.h>

class MenuTextControl : public BTextControl {
	typedef BTextControl inherited;
public:
	// Callback class for letting a client create the menu.
	class Callback
	{
	public:
		Callback(void)
		{
			// empty
		}
		
		virtual ~Callback(void)
		{
			// empty
		}
		
		virtual BPopUpMenu *operator()(const BMessage &msg, BHandler *pTarget) const = 0;

	private:
		Callback(const Callback &);
		Callback &operator =(const Callback &);
	};
	
	// Constructor, destructor.
	MenuTextControl(
		BRect frame,
		const char *pName, const char *pLabel, const char *pInitialText,
		BMessage *pMessage,
		uint32 rmask = B_FOLLOW_LEFT|B_FOLLOW_TOP,
		uint32 flags = B_WILL_DRAW|B_NAVIGABLE); 
	virtual ~MenuTextControl(void);

	// Hook functions.
	virtual void Draw(BRect updateRect);
	virtual void MessageReceived(BMessage *pMsg);
	virtual void MouseDown(BPoint where);

	// Set the menu creation callback.
	void SetCallback(Callback *pCallback);
	
private:
	// Unimplemented copy constructor and assignment operator.
	MenuTextControl(const MenuTextControl &);
	MenuTextControl &operator =(const MenuTextControl &);

	// Message codes.
	enum {
		kReplaceValue = 'rval'
	};
	
	// Calculate frame rectangle for the menu 'button'.
	BRect ArrowFrame(void);
	
	// Dim colors if control is disabled.
	rgb_color AdjustColor(const rgb_color color) const;

	// Data members.
	const Callback *mpCallback;
};

#endif // MENUTEXTCONTROL_H
